@@ -37,7 +37,12 @@ sub get_additional_libs {
     }
   }
   push @list, (keys %rv);
-  push @list, '-lpthread' if ($^O eq 'openbsd');
+  if ($^O eq 'openbsd') {
+    my $osver = `uname -r 2>/dev/null`;
+    if ($self->notes('perl_libs')->{pthread} || ($osver && $osver < 5.0)) {
+      push @list, '-lpthread'
+    }
+  }
   return join(' ', @list);
 }
 
@@ -136,7 +141,7 @@ sub _get_configure_cmd {
 
   # NOTE: all ugly IFs concerning ./configure params have to go here
 
-  if($pack eq 'SDL_gfx' && $uname =~ /(powerpc|ppc|64|2level|alpha|armv5|sparc)/i) {
+  if($pack eq 'SDL_gfx' && $uname =~ /(powerpc|ppc|64|2level|alpha|armv[56]|sparc)/i) {
     $extra .= ' --disable-mmx';
   }
 
@@ -161,8 +166,11 @@ sub _get_configure_cmd {
     $extra .= ' --disable-audio';
   }
 
-  if($pack eq 'SDL' && $^O eq 'openbsd') {
-    $extra_ldflags .= ' -lpthread';
+  if ($pack eq 'SDL' && $^O eq 'openbsd') {
+    my $osver = `uname -r 2>/dev/null`;
+    if (!$self->notes('perl_libs')->{pthread} || !$osver || $osver >= 5.0) {
+      $extra .= ' --disable-pthreads';
+    }
   }
 
   if($pack =~ /^SDL_/) {
