@@ -4,7 +4,7 @@ use warnings;
 use base qw(Exporter);
 
 our @EXPORT_OK = qw(check_config_script check_prebuilt_binaries check_prereqs_libs check_prereqs_tools find_SDL_dir find_file check_header
-                    sed_inplace get_dlext $inc_lib_candidates $source_packs);
+                    sed_inplace get_dlext $inc_lib_candidates $source_packs check_perl_buildlibs);
 use Config;
 use ExtUtils::CBuilder;
 use File::Spec::Functions qw(splitdir catdir splitpath catpath rel2abs);
@@ -194,6 +194,7 @@ our $source_packs = [
           'libsdl-1.2.15-const-xdata32.4.patch',
           'SDL-1.2.15-PIC-in-CFLAGS.patch',
           'SDL-1.2.15-Makefile.in-OBJECTS.patch',
+          'SDL-1.2.15-mavericks-cgdirectpallete.patch',
         ],
         prereqs => {
           libs => [
@@ -286,8 +287,8 @@ our $source_packs = [
         version => '2.0.25',
         dirname => 'SDL_gfx-2.0.25',
         url => [
-          'http://www.ferzkopp.net/Software/SDL_gfx-2.0/SDL_gfx-2.0.25.tar.gz',
           'http://froggs.de/libsdl/SDL_gfx-2.0.25.tar.gz',
+          'http://www.ferzkopp.net/Software/SDL_gfx-2.0/SDL_gfx-2.0.25.tar.gz',
         ],
         sha1sum  => '20a89d0b71b7b790b830c70f17ed2c44100bc0f4',
         patches => [ ],
@@ -418,6 +419,27 @@ sub check_prereqs_libs {
   return $ret;
 }
 
+sub check_perl_buildlibs {
+  my @libs    = @_;
+  my $ret     = 1;
+  my $dlext   = get_dlext();
+  my $devnull = File::Spec->devnull();
+  for my $lib (@libs) {
+    print "checking if perl is linked against $lib... ";
+    if($Config{libs}        =~ /\Q-l$lib\E\b/
+    || $Config{perllibs}    =~ /\Q-l$lib\E\b/
+    || `ldd $^X 2>$devnull` =~ /[\/\\]lib\Q$lib\E[\-\d\.]*\.($dlext[\d\.]*|so|dll)$/) {
+      print "yes\n";
+      $ret &= 1;
+    }
+    else {
+      print "no\n";
+      $ret = 0;
+    }
+  }
+  return $ret;
+}
+
 sub check_prereqs {
   my $bp  = shift;
   my $ret = 1;
@@ -552,7 +574,7 @@ sub get_dlext {
     return 'la';
   }
   else {
-    return $Config{dlext};
+    return $Config{so};
   }
 }
 
